@@ -100,21 +100,38 @@ class Service(object):
     RELEASE_PATH           = '/version/release'
     SCHEME                 = 'http://'
 
-    def __init__(self, root, username=None, password=None):
+    def __init__(self, root, username=None, password=None, token=None):
         """
         Constructor
         ===========
 
         Construct a connection to a webservice::
 
-            service = Service("http://www.flymine.org/query/service")
+            url = "http://www.flymine.org/query/service"
+
+            # An unauthenticated connection - access to all public data
+            service = Service(url)
+
+            # An authenticated connection - access to private and public data
+            service = Service(url, token="ABC123456")
+
 
         @param root: the root url of the webservice (required)
         @param username: your login name (optional)
         @param password: your password (required if a username is given)
+        @param token: your API access token(optional - used in preference to username and password)
 
         @raise ServiceError: if the version cannot be fetched and parsed
         @raise ValueError:   if a username is supplied, but no password
+
+        There are two alternative authentication systems supported by InterMine
+        webservices. The first is username and password authentication, which
+        is supported by all webservices. Newer webservices (version 6+)
+        also support API access token authentication, which is the recommended 
+        system to use. Token access is more secure as you will never have 
+        to transmit your username or password, and the token can be easily changed
+        or disabled without changing your webapp login details.
+
         """
         self.root = root
         self._templates = None
@@ -123,18 +140,27 @@ class Service(object):
         self._release = None
         self._list_manager = ListManager(self)
         self.__missing_method_name = None
-        if username:
+        if token:
+            self.opener = InterMineURLOpener(token=token)
+        elif username:
+            if token:
+                raise ValueError("Both username and token credentials supplied")
+
             if not password:
                 raise ValueError("Username given, but no password supplied")
+
             self.opener = InterMineURLOpener((username, password))
         else:
             self.opener = InterMineURLOpener()
 
-# This works in the real world, but not in testing...
-#       try:
-#           self.version
-#       except ServiceError:
-#           raise ServiceError("Could not validate service - is the root url correct?")
+        try:
+            self.version
+        except WebserviceError:
+            raise ServiceError("Could not validate service - is the root url correct?")
+
+        if token and self.version < 6:
+            raise ServiceError("This service does not support API access token authentication")
+
 
     # Delegated list methods
 
@@ -609,7 +635,7 @@ class InterMineURLOpener(urllib.FancyURLopener):
     """
     version = "InterMine-Python-Client-0.96.00"
 
-    def __init__(self, credentials=None):
+    def __init__(self, credentials=None, token=None):
         """
         Constructor
         ===========
@@ -619,6 +645,7 @@ class InterMineURLOpener(urllib.FancyURLopener):
         Return a new url-opener with the appropriate credentials
         """
         urllib.FancyURLopener.__init__(self)
+        self.token = token
         self.plain_post_header = {
             "Content-Type": "text/plain; charset=utf-8",
             "UserAgent": Service.USER_AGENT
@@ -632,6 +659,7 @@ class InterMineURLOpener(urllib.FancyURLopener):
             self.using_authentication = False
 
     def post_plain_text(self, url, body):
+        url = self.prepare_url(url)
         o = urlparse(url)
         con = httplib.HTTPConnection(o.hostname, o.port)
         con.request('POST', url, body, self.plain_post_header)
@@ -642,7 +670,23 @@ class InterMineURLOpener(urllib.FancyURLopener):
             raise WebserviceError(resp.status, resp.reason, content)
         return content
 
+    def open(self, url, data=None):
+        url = self.prepare_url(url)
+        return urllib.FancyURLopener.open(self, url, data) 
+
+    def prepare_url(self, url):
+        if self.token:
+            token_param = "token=" + self.token
+            o = urlparse(url)
+            if o.query:
+                url += "&" + token_param
+            else:
+                url += "?" + token_param
+
+        return url
+
     def delete(self, url):
+        url = self.prepare_url(url)
         o = urlparse(url)
         con = httplib.HTTPConnection(o.hostname, o.port)
         con.request('DELETE', url, None, self.plain_post_header)
